@@ -15,7 +15,7 @@ import numpy as np
 
 from spyrograph.core._misc import (
     _get_products_of_inputs, _validate_only_one_iterable, _draw_animation,
-    _validate_theta, _save_trace
+    _validate_theta, _save_trace, _get_animate_screen_size
 )
 
 try:
@@ -447,14 +447,7 @@ class _Trochoid(ABC):
             R, r, d, thetas, theta_start,
             theta_stop, theta_step, origin
         )
-        min_x = min(shapes_arr, key=lambda x: x.min_x).min_x
-        max_x = max(shapes_arr, key=lambda x: x.max_x).max_x
-        min_y = min(shapes_arr, key=lambda x: x.min_y).min_y
-        max_y = max(shapes_arr, key=lambda x: x.max_y).max_y
-        screen_size = (
-            max_x - min_x + padding,
-            max_y - min_y + padding
-        )
+        screen_size = _get_animate_screen_size(shapes_arr)
         _draw_animation(
             shapes_arr=shapes_arr, screen_size=screen_size,
             screen_color=screen_color, exit_on_click=exit_on_click, color=color,
